require 'batch_experiment/extractor'

module BatchExperiment
  # A very simple sample extractor that extracts the first line of the
  # command output, the run time and the memory usage (the last two are
  # automatically added to any command output by ::batch and ::experiment).
  module FirstLineExtractor
    extend Extractor
    # (see BatchExperiment::Extractor#names)
    def self.names
      ['first_line', 'ext_time', 'ext_mem']
    end

    # (see BatchExperiment::Extractor#extract_from_lines)
    def self.extract_from_lines(lines)
      [ (lines[0] or ''),
        Extractor.get_field(lines, 'ext_time'),
        Extractor.get_field(lines, 'ext_mem')
      ]
    end
  end

  # Sample extractors used at https://github.com/henriquebecker91/masters,
  # where this code had its beggining. This file contains the code used to
  # extract info from the different outputs generated by UKP solving programs.

  # @private
  # Extractor for the output of the run_ukp5.out program available at
  # https://github.com/henriquebecker91/masters. Not of interest for the
  # majority of the users of this gem. Kept as example, and for this gem author
  # personal use.
  module UKP5Extractor
    extend Extractor
    # (see BatchExperiment::Extractor#names)
    def self.names
      ['internal_time', 'external_time', 'external_memory', 'opt']
    end

    # (see BatchExperiment::Extractor#extract_from_lines)
    def self.extract_from_lines(lines)
      ['Seconds', 'ext_time', 'ext_mem', 'opt'].map do | label |
        Extractor.get_field(lines, label)
      end
    end
  end

  # @private
  # Extractor for the output of the pyasukp program available at
  # https://github.com/henriquebecker91/masters. Not of interest for the
  # majority of the users of this gem. Kept as example, and for this gem author
  # personal use.
  class PyaExtractor
    extend Extractor
    # (see BatchExperiment::Extractor#names)
    def self.names
      ['internal_time', 'external_time', 'external_memory', 'opt']
    end

    # (see BatchExperiment::Extractor#extract_from_lines)
    def self.extract_from_lines(lines)
      values = ['Total Time ', 'ext_time', 'ext_mem'].map do | label |
        Extractor.get_field(lines, label)
      end
      opt_key = '#The optimal value for the given capacity'
      values << Extractor.get_hfield(lines, opt_key)
    end
  end
end
